## SCATTER POINTS IN MAYA
# emits particles on ground plane
# sets initial state
# puts locator at each particle
# deletes particle system

## Written by Jessie Amadio
## Update: Dec 1st, 2014

import maya.cmds as cmds


def scatterPoints():
    
    maxCount: 300
    scatterSurface = 'groundPlaneGEO'
    
	# emits way more particles than desired, but limits with maxCount
	# so they are all born on the first frame, with no inherent forces   
    cmds.select(scatterSurface, r=True)
    cmds.emitter(type='surface', name="ground1", r=50000, sro=0, nuv=0, cye='none', cyi=1, spd=0, srn=0, nsp=0, tsp=0, mxd=0, mnd=0, dx=1, dy=0, dz=0, sp=0)
    cmds.particle(p=(0, 0, 0), c=1)
    cmds.connectDynamic('particle1', em='ground1') 
    cmds.setAttr("particleShape1.maxCount", maxCount)
    
    # save initial state
    cmds.currentTime(2)
    cmds.saveInitialState('particle1')
    cmds.currentTime(1)
    

    
    for p in range(maxCount):
        #finds xform position of each particle
        pos = cmds.xform(('particle1.pt[' + str(p) +']'), q=True, t=True, a=True, ws=True)
        #create locator at particle position
        locator = cmds.spaceLocator()
        cmds.setAttr( (str(locator[0]) + ".translateX"), pos[0])
        cmds.setAttr( (str(locator[0]) + ".translateY"), pos[1])
        cmds.setAttr( (str(locator[0]) + ".translateZ"), pos[2])

		
    cmds.delete('ground1', 'particle1')
    
    cmds.group(cmds.ls('*locator*'), n="loc_grp")
    
scatterPoints()